pub struct SourceFile { /* private fields */ }Expand description
A source file that is identified by its name. Optionally stores the source code and LineIndex.
Cloning a SourceFile is cheap, because it only requires bumping a reference count.
Implementations
Sourceimpl SourceFile
impl SourceFile
pub fn to_source_code(&self) -> SourceCode<'_, '_>
pub fn index(&self) -> &LineIndex
Sourcepub fn source_text(&self) -> &str
pub fn source_text(&self) -> &str
Returns the source code.